@@ -1905,13 +1905,15 @@ class Experiment():
             1,
             sharex='none',
             sharey='none',
-            figsize=(6.5, 4.5),
+            figsize=(7., 4.5),
             num='Raw AC susceptibility'
         )  # 8.27, 11.69 A4
         fig.subplots_adjust(hspace=.5, wspace=.02)
 
+        cmap = cm.get_cmap("tab20")
+
         # Experimental data
-        for experiment in experiments:
+        for eit, experiment in enumerate(experiments):
 
             # Real
             ax1.semilogx(
@@ -1920,7 +1922,8 @@ class Experiment():
                 '-o',
                 markersize=4,
                 fillstyle='none',
-                label='{:.2f} K'.format(experiment.temperatures[0])
+                label='{:.2f} K'.format(experiment.temperatures[0]),
+                color=cmap.colors[eit]
             )
             # Imaginary
             ax2.semilogx(
@@ -1929,7 +1932,7 @@ class Experiment():
                 '-o',
                 markersize=4,
                 fillstyle='none',
-                label='{:.2f} K'.format(experiment.temperatures[0])
+                color=cmap.colors[eit]
             )
 
         ax2.get_shared_x_axes().join(ax1, ax2)
@@ -1947,7 +1950,12 @@ class Experiment():
         ax2.set_xlabel('Wave Frequency (Hz)')
         ax2.set_ylabel(r'$\chi^{,,}$ (cm$^{3}$mol$^{-1}$)')
 
-        fig.legend(frameon=False)
+        fig.legend(
+            frameon=False,
+            loc=7
+        )
+
+        fig.tight_layout(rect=[0, 0, 0.85, 1])
 
         if save:
 
@@ -1996,11 +2004,13 @@ class Experiment():
             1,
             sharex='none',
             sharey='none',
-            figsize=(5.1, 4.8),
+            figsize=(7.1, 4.8),
             num='Raw Cole-Cole'
         )
         fig.subplots_adjust(hspace=.02, wspace=.02)
 
+        cmap = cm.get_cmap("tab20")
+
         # Experimental data
         for eit, experiment in enumerate(experiments):
 
@@ -2012,9 +2022,13 @@ class Experiment():
                 markersize=4,
                 fillstyle='none',
                 label="{:.2f} K".format(experiment.temperatures[0]),
+                color=cmap.colors[eit]
             )
 
-        fig.legend(frameon=False)
+        fig.legend(
+            frameon=False,
+            loc=7
+        )
 
         # Remove frames
         ax1.spines["top"].set_visible(False)
@@ -2024,7 +2038,7 @@ class Experiment():
         ax1.set_xlabel(r'$\chi^{,}$  (cm$^{3}$mol$^{-1}$)')
         ax1.set_ylabel(r'$\chi^{,,}$ (cm$^{3}$mol$^{-1}$)')
 
-        fig.tight_layout()
+        fig.tight_layout(rect=[0, 0, 0.85, 1])
 
         if save:
 
