@@ -244,7 +244,6 @@ def ac_mode_func(args):
         relax.select_model_rates(
             rxp, temperature, 1./tau, 0., _process='tau_vs_T'
         )
-
     return
 
 
@@ -408,7 +407,7 @@ def relaxation_mode_func(args):
 
     # Read-in the rates.
     xvals, tau = rxp.read_rates(
-        args.input_file, args.exe_mode
+        args.input_file, args.exe_mode, sigma=args.sigma
     )
 
     # Select the model function to be used
